Saved

Type Alias Saved 

pub type Saved = BasicListing<SavedData>;
Saved listing

Aliased Type

pub struct Saved {
    pub kind: Option<String>,
    pub data: Listing<BasicThing<SavedData>>,
}

Fields

kind: Option<String>

An identifier that specifies the type of object that this is.

data: Listing<BasicThing<SavedData>>

The data contained by this struct. This will vary depending on the type parameter because each endpoint returns different contents.