pub struct RichtextFlair { /* private fields */ }Expand description
If the API user has user flair in this subreddit, and its user_flair_type is richtext, this will be an array containing two string elements which define the user’s flair.