pub type SubredditsData = BasicListing<SubredditData>;Expand description
Subreddits
Aliased Type
pub struct SubredditsData {
pub kind: Option<String>,
pub data: Listing<BasicThing<SubredditData>>,
}Fields
kind: Option<String>An identifier that specifies the type of object that this is.
data: Listing<BasicThing<SubredditData>>The data contained by this struct. This will vary depending on the type parameter because each endpoint returns different contents.